// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIpKQYJKoZIhvcNAQcCoIIpGjCCKRYCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg30MIIGcjCCBFqgAwIBAgITMwAAA9LaGRZdbcdJrwAA
// SIG // AAAD0jANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTI0MDIyMjIwMjU1MloX
// SIG // DTI1MDIxOTIwMjU1MlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALdqEoU6W4QYwAex/MdHkWVW
// SIG // /KE4Upt5VCyXOoFKiGCkfI4P9VCd0wiGQxD+WK6yL+Eo
// SIG // j/RxpFOy4Q4t/WbiJezoULDKavmxTNRp3z0ZkJfGR5ks
// SIG // YBoM0MItIeAfbqxMuoW6w0q5HncCxJi0x9MJWuhLiQZK
// SIG // VJdlY3Qixxa/PVmBY9PbzPanBhTthMeH03ScbieAeDJc
// SIG // TIbWIyxWrIlawZIwgkkK3bVuJe+tqbNIPKmRSmQWGeDA
// SIG // zkeTzFEehK2YPzHlBleu8yp1Z0a7yecNWh3wl4uxyG62
// SIG // 6YBQQ42xcFhreA5q2VBEgl0nlF24Fa2JVvIDH8Tl2Rtr
// SIG // 3ALpefWetYHsrQd3/JS02w7GR2FKsP0iSlgSbabJCV6B
// SIG // ILmGx/WltmTKxFZw5nuhDaNFkBq4UqEBMRAVEVY8rJ29
// SIG // FgqZjTs5YCTGm+YkjSeRciM+QYahAc6WhaXUCZ0hlWCy
// SIG // WYSc7gg4NbvH02eHPUfgo3UAWkxQGRnL1QG2Gn6XSwju
// SIG // FGud6wIDAQABo4IBgjCCAX4wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFANWxir0
// SIG // XadzyHYXZDqQCRDCKO8/MFQGA1UdEQRNMEukSTBHMS0w
// SIG // KwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRp
// SIG // b25zIExpbWl0ZWQxFjAUBgNVBAUTDTQ2NDIyMys1MDIw
// SIG // ODUwHwYDVR0jBBgwFoAUSG5k5VAF04KqFzc3IrVtqMp1
// SIG // ApUwVAYDVR0fBE0wSzBJoEegRYZDaHR0cDovL3d3dy5t
// SIG // aWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNybDBhBggrBgEFBQcB
// SIG // AQRVMFMwUQYIKwYBBQUHMAKGRWh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNydDAMBgNVHRMBAf8E
// SIG // AjAAMA0GCSqGSIb3DQEBDAUAA4ICAQClGvcxkigIlw60
// SIG // wWETAB6g+IEscqetgjSH9ndL4Po9vCpGs1Vyzl9Fsa0U
// SIG // 3dUv7kC2DsBSAHvQzF3k0hOdwnvLurkzCYwX8T26TacP
// SIG // UgDTy8IbuNBT+cof4Aj9mnuXk3hkbx/Btha9NGqrHBB/
// SIG // rwEz2Fob1WtCst4VsBFsPnfl0BQ+79IktYTB6HVdZy1p
// SIG // BsIQ1/G2cT3NQwMfbVV/L2Svk9NWPqY+xsfG9LkqbTN0
// SIG // VPme18Xuu5mfjtgO7CgR0OtrenSOiQjcPK8f1DukpddH
// SIG // R/0vzOohFqTtbFs1gF//N3E4K0DFD3vAJAQt6ZXYyCSq
// SIG // +j6uiEZ2Tws6KT1fgqD+RhG04iNTGeG0McH2jXpcDj8o
// SIG // 5hTt971pQq0Qfn1ysPHdCcTaP7pzlvXDHnYmVfgf8Ism
// SIG // p+nfZlgcdUB11k4PVDRkniap54Hdodi8n7bwnKXa2Fjb
// SIG // GrZg7Yy6c5uQHcqG8WZtnMXgwPcZDEAKhqPyE7iMtJrU
// SIG // YVtlsQrP9uPcXi9E7nAFcVJmt1g50MrOmuXfAR6x9TRP
// SIG // c7rpiVQQA15bEBNRGAxvFwzPh8pjRZjXJz7Sj+8JDyJ1
// SIG // WOGejwkUVdgg/bPjz+dX8KQmozKzF/Vd6Npa/vxhF4RS
// SIG // DOfhfbsJbSaYeMjlO7U1lOe51nq4n3BOWFJNnUFMZB4M
// SIG // Fl3zJVHkKzCCB3owggVioAMCAQICCmEOkNIAAAAAAAMw
// SIG // DQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRp
// SIG // ZmljYXRlIEF1dGhvcml0eSAyMDExMB4XDTExMDcwODIw
// SIG // NTkwOVoXDTI2MDcwODIxMDkwOVowfjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEoMCYGA1UEAxMfTWljcm9zb2Z0IENvZGUg
// SIG // U2lnbmluZyBQQ0EgMjAxMTCCAiIwDQYJKoZIhvcNAQEB
// SIG // BQADggIPADCCAgoCggIBAKvw+nIQHC6t2G6qghBNNLry
// SIG // tlghn0IbKmvpWlCquAY4GgRJun/DDB7dN2vGEtgL8DjC
// SIG // mQawyDnVARQxQtOJDXlkh36UYCRsr55JnOloXtLfm1Oy
// SIG // CizDr9mpK656Ca/XllnKYBoF6WZ26DJSJhIv56sIUM+z
// SIG // RLdd2MQuA3WraPPLbfM6XKEW9Ea64DhkrG5kNXimoGMP
// SIG // LdNAk/jj3gcN1Vx5pUkp5w2+oBN3vpQ97/vjK1oQH01W
// SIG // KKJ6cuASOrdJXtjt7UORg9l7snuGG9k+sYxd6IlPhBry
// SIG // oS9Z5JA7La4zWMW3Pv4y07MDPbGyr5I4ftKdgCz1TlaR
// SIG // ITUlwzluZH9TupwPrRkjhMv0ugOGjfdf8NBSv4yUh7zA
// SIG // IXQlXxgotswnKDglmDlKNs98sZKuHCOnqWbsYR9q4ShJ
// SIG // nV+I4iVd0yFLPlLEtVc/JAPw0XpbL9Uj43BdD1FGd7P4
// SIG // AOG8rAKCX9vAFbO9G9RVS+c5oQ/pI0m8GLhEfEXkwcNy
// SIG // euBy5yTfv0aZxe/CHFfbg43sTUkwp6uO3+xbn6/83bBm
// SIG // 4sGXgXvt1u1L50kppxMopqd9Z4DmimJ4X7IvhNdXnFy/
// SIG // dygo8e1twyiPLI9AN0/B4YVEicQJTMXUpUMvdJX3bvh4
// SIG // IFgsE11glZo+TzOE2rCIF96eTvSWsLxGoGyY0uDWiIwL
// SIG // AgMBAAGjggHtMIIB6TAQBgkrBgEEAYI3FQEEAwIBADAd
// SIG // BgNVHQ4EFgQUSG5k5VAF04KqFzc3IrVtqMp1ApUwGQYJ
// SIG // KwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQD
// SIG // AgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU
// SIG // ci06AjGQQ7kUBU7h6qfHMdEjiTQwWgYDVR0fBFMwUTBP
// SIG // oE2gS4ZJaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0MjAxMV8y
// SIG // MDExXzAzXzIyLmNybDBeBggrBgEFBQcBAQRSMFAwTgYI
// SIG // KwYBBQUHMAKGQmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0MjAxMV8yMDEx
// SIG // XzAzXzIyLmNydDCBnwYDVR0gBIGXMIGUMIGRBgkrBgEE
// SIG // AYI3LgMwgYMwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cu
// SIG // bWljcm9zb2Z0LmNvbS9wa2lvcHMvZG9jcy9wcmltYXJ5
// SIG // Y3BzLmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBwAG8AbABpAGMAeQBfAHMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAZ/KGpZjg
// SIG // VHkaLtPYdGcimwuWEeFjkplCln3SeQyQwWVfLiw++MNy
// SIG // 0W2D/r4/6ArKO79HqaPzadtjvyI1pZddZYSQfYtGUFXY
// SIG // DJJ80hpLHPM8QotS0LD9a+M+By4pm+Y9G6XUtR13lDni
// SIG // 6WTJRD14eiPzE32mkHSDjfTLJgJGKsKKELukqQUMm+1o
// SIG // +mgulaAqPyprWEljHwlpblqYluSD9MCP80Yr3vw70L01
// SIG // 724lruWvJ+3Q3fMOr5kol5hNDj0L8giJ1h/DMhji8MUt
// SIG // zluetEk5CsYKwsatruWy2dsViFFFWDgycScaf7H0J/je
// SIG // LDogaZiyWYlobm+nt3TDQAUGpgEqKD6CPxNNZgvAs031
// SIG // 4Y9/HG8VfUWnduVAKmWjw11SYobDHWM2l4bf2vP48hah
// SIG // mifhzaWX0O5dY0HjWwechz4GdwbRBrF1HxS+YWG18NzG
// SIG // GwS+30HHDiju3mUv7Jf2oVyW2ADWoUa9WfOXpQlLSBCZ
// SIG // gB/QACnFsZulP0V3HjXG0qKin3p6IvpIlR+r+0cjgPWe
// SIG // +L9rt0uX4ut1eBrs6jeZeRhL/9azI2h15q/6/IvrC4Dq
// SIG // aTuv/DDtBEyO3991bWORPdGdVk5Pv4BXIqF4ETIheu9B
// SIG // CrE/+6jMpF3BoYibV3FWTkhFwELJm3ZbCoBIa/15n8G9
// SIG // bW1qyVJzEw16UM0xghqNMIIaiQIBATCBlTB+MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
// SIG // Q29kZSBTaWduaW5nIFBDQSAyMDExAhMzAAAD0toZFl1t
// SIG // x0mvAAAAAAPSMA0GCWCGSAFlAwQCAQUAoIGuMBkGCSqG
// SIG // SIb3DQEJAzEMBgorBgEEAYI3AgEEMBwGCisGAQQBgjcC
// SIG // AQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEi
// SIG // BCD3omjKU+2ltBtHmjuFe7vjmLFCFgQ9lehLg9Wo3349
// SIG // uDBCBgorBgEEAYI3AgEMMTQwMqAUgBIATQBpAGMAcgBv
// SIG // AHMAbwBmAHShGoAYaHR0cDovL3d3dy5taWNyb3NvZnQu
// SIG // Y29tMA0GCSqGSIb3DQEBAQUABIIBgJwRV05KItkzV8mS
// SIG // h7DU4h0aJuAhHdKU/r7ZrUMDtdMP4v6LHog50vm6c+g+
// SIG // vhOMNWgOU5/dHu58CeygxRDoQ7kMypYv/PyX61YGCmG/
// SIG // F2D6mx5Z/SZZl3ck8jyqDz8VbVLLQ+HYn9Nq3MSD+vUO
// SIG // lpozQ/uliFptv0bJ69LzItoTCwpgQ3lenUrqZZwWQE3q
// SIG // DB1qmV5ZvM0cnAbQAbLe/TqHkux9YqxbvD0cJcgfVkOZ
// SIG // 3HNF+r5B2mbz6VizZScLwITYpsGBcr3hTl1QVMkua4Co
// SIG // 9kRmrRJji26KncB5KdgFifA+8kmgHFtx4mCCPqX9w+lk
// SIG // wZjFlrDuBgLxE1h5rxwPdB5SDlSsI23edgZJxP6iFUz3
// SIG // OQEhojFJIwwiFt0w8UeiXLSH2yWdQF1ZusbXUqw9MXXN
// SIG // jp4TBweAfScQteJefejuBJQruqlMj/iKXKWyyJf3f9nO
// SIG // pCWot1VRclW8/CsXiM4mQiSCRk7srqoFRCAkKfIEpnNj
// SIG // pUaPBPIHCBNggqGCF5cwgheTBgorBgEEAYI3AwMBMYIX
// SIG // gzCCF38GCSqGSIb3DQEHAqCCF3AwghdsAgEDMQ8wDQYJ
// SIG // YIZIAWUDBAIBBQAwggFSBgsqhkiG9w0BCRABBKCCAUEE
// SIG // ggE9MIIBOQIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
// SIG // AwQCAQUABCCWE/Ksq9FtHsJiyB7tp1/e4Hm6d59pHQQJ
// SIG // seKXo5yFjgIGZuMo+0PwGBMyMDI0MDkyMDIwNDc1Ni44
// SIG // MzZaMASAAgH0oIHRpIHOMIHLMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBP
// SIG // cGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxkIFRTUyBF
// SIG // U046MzMwMy0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jv
// SIG // c29mdCBUaW1lLVN0YW1wIFNlcnZpY2WgghHtMIIHIDCC
// SIG // BQigAwIBAgITMwAAAebZQp7qAPh94QABAAAB5jANBgkq
// SIG // hkiG9w0BAQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMDAeFw0yMzEyMDYxODQ1MTVaFw0yNTAzMDUxODQ1
// SIG // MTVaMIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
// SIG // aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
// SIG // ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQL
// SIG // ExxNaWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMScw
// SIG // JQYDVQQLEx5uU2hpZWxkIFRTUyBFU046MzMwMy0wNUUw
// SIG // LUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0
// SIG // YW1wIFNlcnZpY2UwggIiMA0GCSqGSIb3DQEBAQUAA4IC
// SIG // DwAwggIKAoICAQC9vph84tgluEzm/wpNKlAjcElGzflv
// SIG // KADZ1D+2d/ieYYEtF2HKMrKGFDOLpLWWG5DEyiKblYKr
// SIG // E2nt540OGu35Zx0gXJBE0zWanZEAjCjt4eGBi+uakZsk
// SIG // 70zHTQHHyfP+B3m2BSSNFPhgsVIPp6vo/9t6OeNezIwX
// SIG // 5E5+VwEG37nZgEexQF2fQZYbxQ1AauqDvRdXsSpK1dh1
// SIG // UBt9EaMszuucaR5nMwQN6sDjG99FzdK9Atzbn4SmlsoL
// SIG // UtRAh/768sKd0Y1hMmKVHwIX8/4JuURUBRZ0JWu0NYQB
// SIG // p8khku18Q8CAQ500tFB7VH3pD8zoA4lcA7JkxTGoPKru
// SIG // fm+lRZAA4iMgbcLZ2P/xSdnKFxU8vL31RoNlZJiGL5Mq
// SIG // TXvvyBLz+MRP4En9Nye1N8x/lJD1stdNo5wJG+mgXsE/
// SIG // zfzg2GaVqQczFHg0Nl8bpIqnNFUReQRq3C1jVYMCSceg
// SIG // NzHeYtw5OmZ/7eVnRmjXlCsLvdsxOzc1YVn6nZLkQD5y
// SIG // 31HYrB9iIHuswhaMv2hJNNjVndkpWy934PIZuWTMk360
// SIG // kjXPFwl2Wv1Tzm9tOrCq8+l408KIL6J+efoGNkR8YB3M
// SIG // +u1tYeVDO/TcObGHxaGFB6QZxAUpnfB5N/MmBNxMOqzG
// SIG // 1N8QiwW8gtjjMJiFBf6iYYrCjtRwF7IPdQLFtQIDAQAB
// SIG // o4IBSTCCAUUwHQYDVR0OBBYEFOUEMXntN54+11ZM+Qu7
// SIG // Q5rg3Fc9MB8GA1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWn
// SIG // G1M1GelyMF8GA1UdHwRYMFYwVKBSoFCGTmh0dHA6Ly93
// SIG // d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jv
// SIG // c29mdCUyMFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEp
// SIG // LmNybDBsBggrBgEFBQcBAQRgMF4wXAYIKwYBBQUHMAKG
// SIG // UGh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMv
// SIG // Y2VydHMvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBD
// SIG // QSUyMDIwMTAoMSkuY3J0MAwGA1UdEwEB/wQCMAAwFgYD
// SIG // VR0lAQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQD
// SIG // AgeAMA0GCSqGSIb3DQEBCwUAA4ICAQBhbuogTapRsuwS
// SIG // kaFMQ6dyu8ZCYUpWQ8iIrbi40tU2hK6pHgu0hj0z/9zF
// SIG // RRx5DfhukjvbjA/dS5VYfxz1EIbPlt897MJ2sBGO2YLY
// SIG // wYelfJpDwbB0XS9Zkrqpzq6X/lmDQDn3G5vcYpYQCJ55
// SIG // LLvyFlJ195AVo4Wy8UX5p7g9W3MgNHQMpM+EV64+cszj
// SIG // 4Ho5aQmeKGtKy7w72eRY/vWDuptrvzruFNmKCIt12UcA
// SIG // 5BOsXp1Ptkjx2yRsCj77DSml0zVYjqW/ISWkrGjyeVJ+
// SIG // khzctxaLkklVwCxigokD6fkWby0hCEKTOTPMzhugPIAc
// SIG // xcHsR2sx01YRa9pH2zvddsuBEfSFG6Cj0QSvEZ/M9mJ+
// SIG // h4miaQSR7AEbVGDbyRKkYn80S+3AmRlh3ZOe+BFqJ57O
// SIG // XdeIDSHbvHzJ7oTqG896l3eUhPsZg69fNgxTxlvRNmRE
// SIG // /+61Yj7Z1uB0XYQP60rsMLdTlVYEyZUl5MLTL5LvqFoz
// SIG // ZlS2Xoji4BEP6ddVTzmHJ4odOZMWTTeQ0IwnWG98vWv/
// SIG // roPegCr1G61FVrdXLE3AXIft4ZN4ZkDTnoAhPw7DZNPR
// SIG // lSW4TbVj/Lw0XvnLYNwMUA9ouY/wx9teTaJ8vTkbgYya
// SIG // OYKFz6rNRXZ4af6e3IXwMCffCaspKUXC72YMu5W8L/zy
// SIG // TxsNUEgBbTCCB3EwggVZoAMCAQICEzMAAAAVxedrngKb
// SIG // SZkAAAAAABUwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNV
// SIG // BAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
// SIG // VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
// SIG // Q29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBS
// SIG // b290IENlcnRpZmljYXRlIEF1dGhvcml0eSAyMDEwMB4X
// SIG // DTIxMDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVowfDEL
// SIG // MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
// SIG // EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
// SIG // c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9z
// SIG // b2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqG
// SIG // SIb3DQEBAQUAA4ICDwAwggIKAoICAQDk4aZM57RyIQt5
// SIG // osvXJHm9DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25
// SIG // PhdgM/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLA
// SIG // EBjoYH1qUoNEt6aORmsHFPPFdvWGUNzBRMhxXFExN6AK
// SIG // OG6N7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6
// SIG // GnszrYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v
// SIG // 3byNpOORj7I5LFGc6XBpDco2LXCOMcg1KL3jtIckw+DJ
// SIG // j361VI/c+gVVmG1oO5pGve2krnopN6zL64NF50ZuyjLV
// SIG // wIYwXE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4d
// SIG // Pf0gz3N9QZpGdc3EXzTdEonW/aUgfX782Z5F37ZyL9t9
// SIG // X4C626p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0lBw0gg/w
// SIG // EPK3Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8Qmgu
// SIG // EOqEUUbi0b1qGFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoS
// SIG // CtdjbwzJNmSLW6CmgyFdXzB0kZSU2LlQ+QuJYfM2BjUY
// SIG // hEfb3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzFER1y7435
// SIG // UsSFF5PAPBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57
// SIG // t7c+auIurQIDAQABo4IB3TCCAdkwEgYJKwYBBAGCNxUB
// SIG // BAUCAwEAATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6C
// SIG // kTxGNSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl
// SIG // 0mWnG1M1GelyMFwGA1UdIARVMFMwUQYMKwYBBAGCN0yD
// SIG // fQEBMEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5
// SIG // Lmh0bTATBgNVHSUEDDAKBggrBgEFBQcDCDAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbL
// SIG // j+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEugSaBH
// SIG // hkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0y
// SIG // My5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUFBzAC
// SIG // hj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2Nl
// SIG // cnRzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDAN
// SIG // BgkqhkiG9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvh
// SIG // nnJL/Klv6lwUtj5OR2R4sQaTlz0xM7U518JxNj/aZGx8
// SIG // 0HU5bbsPMeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYu
// SIG // nKmCVgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5t
// SIG // ggz1bSNU5HhTdSRXud2f8449xvNo32X2pFaq95W2KFUn
// SIG // 0CS9QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wM
// SIG // nosZiefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU
// SIG // 6ZGyqVvfSaN0DLzskYDSPeZKPmY7T7uG+jIa2Zb0j/aR
// SIG // AfbOxnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2dY3RI
// SIG // LLFORy3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltE
// SIG // AY5aGZFrDZ+kKNxnGSgkujhLmm77IVRrakURR6nxt67I
// SIG // 6IleT53S0Ex2tVdUCbFpAUR+fKFhbHP+CrvsQWY9af3L
// SIG // wUFJfn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcdFYmN
// SIG // cP7ntdAoGokLjzbaukz5m/8K6TT4JDVnK+ANuOaMmdbh
// SIG // IurwJ0I9JZTmdHRbatGePu1+oDEzfbzL6Xu/OHBE0ZDx
// SIG // yKs6ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQdVTNYs6Fw
// SIG // ZvKhggNQMIICOAIBATCB+aGB0aSBzjCByzELMAkGA1UE
// SIG // BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
// SIG // BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFt
// SIG // ZXJpY2EgT3BlcmF0aW9uczEnMCUGA1UECxMeblNoaWVs
// SIG // ZCBUU1MgRVNOOjMzMDMtMDVFMC1EOTQ3MSUwIwYDVQQD
// SIG // ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMK
// SIG // AQEwBwYFKw4DAhoDFQDiWNBeFJ9jvaErN64D1G86eL0m
// SIG // u6CBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAk
// SIG // BgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
// SIG // MDEwMA0GCSqGSIb3DQEBCwUAAgUA6pgypDAiGA8yMDI0
// SIG // MDkyMDE3NDMwMFoYDzIwMjQwOTIxMTc0MzAwWjB3MD0G
// SIG // CisGAQQBhFkKBAExLzAtMAoCBQDqmDKkAgEAMAoCAQAC
// SIG // AiKPAgH/MAcCAQACAhOsMAoCBQDqmYQkAgEAMDYGCisG
// SIG // AQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEA
// SIG // AgMHoSChCjAIAgEAAgMBhqAwDQYJKoZIhvcNAQELBQAD
// SIG // ggEBAHTCkqBrR1+RpRtGipd9lAwe2n5fi9LvK95Y7MOg
// SIG // Tqq26cDU4vXpC3a5IwsgXnn0kwXnbjTqVScY6hG/oCwl
// SIG // pxMXuikUcaKxE58SV3+wI2oMgCQv14mCrX6Ii+PhFLjn
// SIG // oOUryjQkY/LokMso0G0FKF28QcvKVCqQncslSS5y8Blx
// SIG // aJzPcTTKP+L9ez1o4noX1a21dPOFAsI39mFnWqrzUDz5
// SIG // FM9FTjfwhZpAn5lqITTGUCGelV9hGqNqNXnhQF3+qUPT
// SIG // C73KFN2A8UIqv36raV5MjedB1eYiqm6DEx7UoBU1DEI3
// SIG // AlADtu7UtihG5RUEGau4mc6F2siObK6+KLPSTSkxggQN
// SIG // MIIECQIBATCBkzB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMAITMwAAAebZQp7qAPh94QABAAAB5jANBglghkgB
// SIG // ZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3
// SIG // DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCB27N9HSxSR8U4f
// SIG // K9OD8UqC6J43mzm+XiZL1i7I/gCXsjCB+gYLKoZIhvcN
// SIG // AQkQAi8xgeowgecwgeQwgb0EIM+7o4aoHrMJaG8gnLO1
// SIG // q16hIYcRnoy6FnOCbnSD0sZZMIGYMIGApH4wfDELMAkG
// SIG // A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
// SIG // BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
// SIG // dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0
// SIG // IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAHm2UKe6gD4
// SIG // feEAAQAAAeYwIgQgL3bdhPj1Wzj9DMPMejHcmeDmj4Ri
// SIG // GL4Ws25Ahh022d4wDQYJKoZIhvcNAQELBQAEggIAQEiu
// SIG // sQB51JiaSFOgX2ippPPoXKBXsXwWOd0XLsCQxmWCBqxq
// SIG // eb48JsDHDfRvmDTizpZx/m4gDrZY11u34UepkUKLULks
// SIG // RQ8DVJKdHL3r7lQRRYtqve2enZYB8aaoAuQyCZmebpQt
// SIG // YFXzNH1BrWj1pzjF+nvbznIHg4XJSFUAxcGDVMEZfraw
// SIG // Nh51aahO5ierk9ZOeoNzzSZIzDa3n2z4EE0rWrtap2zb
// SIG // 81wZHGTSzMn/vjz42MZ/CYbwAFdbG4y05wIzHu5EdU9+
// SIG // yHs6hOBg0TkOdAekYDwbsMMj2ltz+TE0nNFYo/cJzOv5
// SIG // J2t6TZAKIkjj6ERcAyvlxd7/tLhWuEhWMZ511WNRkdjn
// SIG // kMlJDCv3yzvhm72mQdRaLhS5zWOrhLRzea8Tmcfj18eZ
// SIG // +Wdj61oKNf9kgqizoTHeG0Tz5yI+ZqcPsufCuWdA7Y34
// SIG // 6LD6Q+TcA+jLkNpqNdWByNv5RSSvvT+HWy3nXFOVMuOO
// SIG // 0GTTpqqexo+BIqf5Ta4SIDbyCB00YyVm0HjEZSiCrulA
// SIG // xi53A/HAHzfUpZreJYjaWh0vMmxfloCDhWztEGy3VFcc
// SIG // pjXnAPq8V93jZ7ijc3FYleAshsjoY0V+Lod0YzyrKnyD
// SIG // OssR9t9gvj1gNtv2sgBIBI3mgkO0Bt+ROau6RYaxVbTq
// SIG // 1S4td8Y0q9td3gYkiIQ=
// SIG // End signature block
