// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIpFwYJKoZIhvcNAQcCoIIpCDCCKQQCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg3lMIIGYzCCBEugAwIBAgITMwAAA9N2adyA7AGiQwAA
// SIG // AAAD0zANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTI0MDIyMjIwMjU1M1oX
// SIG // DTI1MDIxOTIwMjU1M1owYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAKJr3WFboo8hjvYLGY3tI6in
// SIG // 98ttqRApdb+QVUtt4qzOjUU6jzJlR6iWCzkQ6U4ZNeAY
// SIG // 5j5ulAqD5Mx3+hzxMp4UULNmq6FF/8oiCEqhbcYJSlys
// SIG // pVtRb7GO8XUSKv5wVV1hNrmpnzOx4n2u90eZ+ehFBuDc
// SIG // cISaiYFtrbQZCS9hZXxoeSyV86iVs9QaetHojvUytJbj
// SIG // tem7TWJvvaDDosYeRaX2wDtTaAJVSc0X4O3wIHazcUFW
// SIG // P1dou65fB/M4L7oCyEGbeqiRrDE4ksyFF9CVAe45UlIc
// SIG // x9b/8gFpV9YrLGgC3XQlZSYDW0ZF2hC1N8CJzQJrilYj
// SIG // kgNOsVJbDHmfo6L9IErSlhESxsnjDNmHfexUPtrdpHR2
// SIG // 1y4tXouxMlGwySrgjvoTrB5591LkXOOkGu7GrGDKAyaI
// SIG // YFKhwOIalmZ13amE/wZxvxwYZJSEMukp5Inl4fjxpa95
// SIG // o/UTsNorMJuKDeVb2mx7bdyL9hLE5W0e1y55JjKFQhMk
// SIG // zAKCTQIDAQABo4IBczCCAW8wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFE2mlO7W
// SIG // 4hvp78Q62SxRXXxDhfwBMEUGA1UdEQQ+MDykOjA4MR4w
// SIG // HAYDVQQLExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xFjAU
// SIG // BgNVBAUTDTQ2NDIyMys1MDIwODIwHwYDVR0jBBgwFoAU
// SIG // SG5k5VAF04KqFzc3IrVtqMp1ApUwVAYDVR0fBE0wSzBJ
// SIG // oEegRYZDaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNybDBhBggrBgEFBQcBAQRVMFMwUQYIKwYBBQUH
// SIG // MAKGRWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvY2VydHMvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEB
// SIG // DAUAA4ICAQB3r7H5qjR/FMblgKoQkNcyxHetl73OlwKt
// SIG // Uo17y5RBmB4IScr/hNt1wm55xj+HYUXyBXD2nCCcxJmC
// SIG // BpJr4WCXtqBP6YPuOo7lFMzFYVi+Q9ck8TOxiaLyJP7G
// SIG // 3IBsyHiHUhIoay7rgpFO0/de0TQ0NU0oCXmgMT6aw6rL
// SIG // nOuazEKUQZW1trU6TmqwC6aFOIRFpPeYxp/K1b9j5XHD
// SIG // 930AOkIlHXe+20WRPvfcph6uZ/Loak9IkJ4hs7wA4rHr
// SIG // xbBwztQFAblZfPmQyFqQLYPP1GpVmZXSdEHzTBKn88kW
// SIG // NbLC44mAhkVREdiATG2B2mecJDZXymFH4oTJw64cBH1D
// SIG // QIdkiubrI46zE9Utuk4LwO74cQUcwH+4qJbDsxBjoLIk
// SIG // +yesxZmaJWgqyxHZGZe+abmkbQpGzUJwd5TyH45Yb5HR
// SIG // DIpjKjbbjskVBY9d2zJGoh3v1sZ3xPdiO5sMmmYZwjr4
// SIG // 5IX/CiQxWzntUY86ocANs0cDRKRvpvma/cbLrakNLuXd
// SIG // ciuYY8uQvTpKwtwj4IcVZrXAIV+NuE297VOcgI60JFZ9
// SIG // jnPwFnRvtj7EKNY3dpZPP8NUnEAUTEr6X3TRd20wUgsa
// SIG // yah8aGYCtyz7XmhHsXqCTrtquP2L22dAumcvLUazDIBB
// SIG // YSoVWxWDfF8CqPLTzXWcTiVreXz5wxtfGjCCB3owggVi
// SIG // oAMCAQICCmEOkNIAAAAAAAMwDQYJKoZIhvcNAQELBQAw
// SIG // gYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1p
// SIG // Y3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
// SIG // eSAyMDExMB4XDTExMDcwODIwNTkwOVoXDTI2MDcwODIx
// SIG // MDkwOVowfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UE
// SIG // AxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAx
// SIG // MTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
// SIG // AKvw+nIQHC6t2G6qghBNNLrytlghn0IbKmvpWlCquAY4
// SIG // GgRJun/DDB7dN2vGEtgL8DjCmQawyDnVARQxQtOJDXlk
// SIG // h36UYCRsr55JnOloXtLfm1OyCizDr9mpK656Ca/XllnK
// SIG // YBoF6WZ26DJSJhIv56sIUM+zRLdd2MQuA3WraPPLbfM6
// SIG // XKEW9Ea64DhkrG5kNXimoGMPLdNAk/jj3gcN1Vx5pUkp
// SIG // 5w2+oBN3vpQ97/vjK1oQH01WKKJ6cuASOrdJXtjt7UOR
// SIG // g9l7snuGG9k+sYxd6IlPhBryoS9Z5JA7La4zWMW3Pv4y
// SIG // 07MDPbGyr5I4ftKdgCz1TlaRITUlwzluZH9TupwPrRkj
// SIG // hMv0ugOGjfdf8NBSv4yUh7zAIXQlXxgotswnKDglmDlK
// SIG // Ns98sZKuHCOnqWbsYR9q4ShJnV+I4iVd0yFLPlLEtVc/
// SIG // JAPw0XpbL9Uj43BdD1FGd7P4AOG8rAKCX9vAFbO9G9RV
// SIG // S+c5oQ/pI0m8GLhEfEXkwcNyeuBy5yTfv0aZxe/CHFfb
// SIG // g43sTUkwp6uO3+xbn6/83bBm4sGXgXvt1u1L50kppxMo
// SIG // pqd9Z4DmimJ4X7IvhNdXnFy/dygo8e1twyiPLI9AN0/B
// SIG // 4YVEicQJTMXUpUMvdJX3bvh4IFgsE11glZo+TzOE2rCI
// SIG // F96eTvSWsLxGoGyY0uDWiIwLAgMBAAGjggHtMIIB6TAQ
// SIG // BgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUSG5k5VAF
// SIG // 04KqFzc3IrVtqMp1ApUwGQYJKwYBBAGCNxQCBAweCgBT
// SIG // AHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
// SIG // MAMBAf8wHwYDVR0jBBgwFoAUci06AjGQQ7kUBU7h6qfH
// SIG // MdEjiTQwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2Ny
// SIG // bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
// SIG // TWljUm9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNybDBe
// SIG // BggrBgEFBQcBAQRSMFAwTgYIKwYBBQUHMAKGQmh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWlj
// SIG // Um9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNydDCBnwYD
// SIG // VR0gBIGXMIGUMIGRBgkrBgEEAYI3LgMwgYMwPwYIKwYB
// SIG // BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
// SIG // a2lvcHMvZG9jcy9wcmltYXJ5Y3BzLmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBwAG8AbABpAGMA
// SIG // eQBfAHMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAZ/KGpZjgVHkaLtPYdGcimwuWEeFj
// SIG // kplCln3SeQyQwWVfLiw++MNy0W2D/r4/6ArKO79HqaPz
// SIG // adtjvyI1pZddZYSQfYtGUFXYDJJ80hpLHPM8QotS0LD9
// SIG // a+M+By4pm+Y9G6XUtR13lDni6WTJRD14eiPzE32mkHSD
// SIG // jfTLJgJGKsKKELukqQUMm+1o+mgulaAqPyprWEljHwlp
// SIG // blqYluSD9MCP80Yr3vw70L01724lruWvJ+3Q3fMOr5ko
// SIG // l5hNDj0L8giJ1h/DMhji8MUtzluetEk5CsYKwsatruWy
// SIG // 2dsViFFFWDgycScaf7H0J/jeLDogaZiyWYlobm+nt3TD
// SIG // QAUGpgEqKD6CPxNNZgvAs0314Y9/HG8VfUWnduVAKmWj
// SIG // w11SYobDHWM2l4bf2vP48hahmifhzaWX0O5dY0HjWwec
// SIG // hz4GdwbRBrF1HxS+YWG18NzGGwS+30HHDiju3mUv7Jf2
// SIG // oVyW2ADWoUa9WfOXpQlLSBCZgB/QACnFsZulP0V3HjXG
// SIG // 0qKin3p6IvpIlR+r+0cjgPWe+L9rt0uX4ut1eBrs6jeZ
// SIG // eRhL/9azI2h15q/6/IvrC4DqaTuv/DDtBEyO3991bWOR
// SIG // PdGdVk5Pv4BXIqF4ETIheu9BCrE/+6jMpF3BoYibV3FW
// SIG // TkhFwELJm3ZbCoBIa/15n8G9bW1qyVJzEw16UM0xghqK
// SIG // MIIahgIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDExAhMzAAAD03Zp3IDsAaJDAAAAAAPTMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCCk0LbOeo0Jl3UzqyYc
// SIG // R3jw0T+iGBzKrXSBXSbuitilgzBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBgJxBuL6753Wjjv56xg8VzPXFcJ6Tmv9LrGcq
// SIG // hvPe+iGEB5xUKag2cBOUNGx/csuBWPCEaEJegx3bkPaV
// SIG // KlogDn+YeI8GCfgJCT+/0V5q+Qd2WTaGKvKAjgRCPfLg
// SIG // xbqcCXK2cx516w8NAq1269pOsfoM5NVw4muGiv8rlnul
// SIG // 9oSR9LboxC6R4v3r/NCVzOHOLw7BOfLY0EszRzdqOC4m
// SIG // g0B3N4OWwnUB3EL1ieRbXiDZJC1EZCFxi3QxffFXVhDL
// SIG // nkm2WUuzREYTw1vX4JWO+HwoKBxz1OdnoEQr5NMLtaWR
// SIG // uR9e783N0LXktxE/tYnWM7fngRhcqdjp3L5TqBBTwRFX
// SIG // qiS+vQ11BAAnxE7WfXLAU5E5PIZtE3Ej2NXuy+b48uTv
// SIG // iVRXDNtb+7HIsIyIyxjhMmBzj+hqPyulkD7LKA+QroUC
// SIG // 8t5WJw4F+KTP/y1HhWCqZhIyEfEJ9FMBTcwrqOwr9Y+U
// SIG // cebXZ0zwXmv7Prv/y0LHbJp29h3iqrkVvvAq5KGCF5Qw
// SIG // gheQBgorBgEEAYI3AwMBMYIXgDCCF3wGCSqGSIb3DQEH
// SIG // AqCCF20wghdpAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFS
// SIG // BgsqhkiG9w0BCRABBKCCAUEEggE9MIIBOQIBAQYKKwYB
// SIG // BAGEWQoDATAxMA0GCWCGSAFlAwQCAQUABCCsXOHWwBVC
// SIG // AKqRcUm5rwITG90OHMOZrpa4RS5DPWUybAIGZuLQ+g/d
// SIG // GBMyMDI0MDkyMDIwNDc1NC43MTZaMASAAgH0oIHRpIHO
// SIG // MIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxN
// SIG // aWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMScwJQYD
// SIG // VQQLEx5uU2hpZWxkIFRTUyBFU046QTQwMC0wNUUwLUQ5
// SIG // NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFNlcnZpY2WgghHqMIIHIDCCBQigAwIBAgITMwAAAezg
// SIG // K6SC0JFSgAABAAAB7DANBgkqhkiG9w0BAQsFADB8MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3Nv
// SIG // ZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0yMzEyMDYx
// SIG // ODQ1MzhaFw0yNTAzMDUxODQ1MzhaMIHLMQswCQYDVQQG
// SIG // EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
// SIG // BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
// SIG // cnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1l
// SIG // cmljYSBPcGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxk
// SIG // IFRTUyBFU046QTQwMC0wNUUwLUQ5NDcxJTAjBgNVBAMT
// SIG // HE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2UwggIi
// SIG // MA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCwR/Ru
// SIG // CTbgxUWVm/Vdul22uwdEZm0IoAFs6oIr39VK/ItP80cn
// SIG // +8TmtP67iabB4DmAKJ9GH6dJGhEPJpY4vTKRSOwrRNxV
// SIG // IKoPPeUF3f4VyHEco/u1QUadlwD132NuZCxbnh6Mi2lL
// SIG // G7pDvszZqMG7S3MCi2bk2nvtGKdeAIL+H77gL4r01TSW
// SIG // b7rsE2Jb1P/N6Y/W1CqDi1/Ib3/zRqWXt4zxvdIGcPjS
// SIG // 4ZKyQEF3SEZAq4XIjiyowPHaqNbZxdf2kWO/ajdfTU85
// SIG // t934CXAinb0o+uQ9KtaKNLVVcNf5QpS4f6/MsXOvIFuC
// SIG // YMRdKDjpmvowAeL+1j27bCxCBpDQHrWkfPzZp/X+bt9C
// SIG // 7E5hPP6HVRoqBYR7u1gUf5GEq+5r1HA0jajn0Q6OvfYc
// SIG // kE0HdOv6KWa+sAmJG7PDvTZae77homzx6IPqggVpNZuC
// SIG // k79SfVmnKu9F58UAnU58TqDHEzGsQnMUQKstS3zjn6SU
// SIG // 0NLEFNCetluaKkqWDRVLEWbu329IEh3tqXPXfy6Rh/wC
// SIG // bwe9SCJIoqtBexBrPyQYA2Xaz1fK9ysTsx0kA9V1JwVV
// SIG // 44Ia9c+MwtAR6sqKdAgRo/bs/Xu8gua8LDe6KWyu974e
// SIG // 9mGW7ZO8narDFrAT1EXGHDueygSKvv2K7wB8lAgMGJj7
// SIG // 3CQvr+jqoWwx6XdyeQIDAQABo4IBSTCCAUUwHQYDVR0O
// SIG // BBYEFPRa0Edk/iv1whYQsV8UgEf4TIWGMB8GA1UdIwQY
// SIG // MBaAFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMF8GA1UdHwRY
// SIG // MFYwVKBSoFCGTmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2lvcHMvY3JsL01pY3Jvc29mdCUyMFRpbWUtU3Rh
// SIG // bXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBsBggrBgEFBQcB
// SIG // AQRgMF4wXAYIKwYBBQUHMAKGUGh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljcm9zb2Z0
// SIG // JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3J0
// SIG // MAwGA1UdEwEB/wQCMAAwFgYDVR0lAQH/BAwwCgYIKwYB
// SIG // BQUHAwgwDgYDVR0PAQH/BAQDAgeAMA0GCSqGSIb3DQEB
// SIG // CwUAA4ICAQCSvMSkMSrvjlDPag8ARb0OFrAQtSLMDpN0
// SIG // UY3FjvPhwGKDrrixmnuMfjrmVjRq1u8IhkDvGF/bffbF
// SIG // Tr+IAnDSeg8TB9zfG/4ybknuopklbeGjbt7MLxpfholC
// SIG // ERyEc20PMZKJz9SvzfuO1n5xrrLOL8m0nmv5kBcv+y1A
// SIG // XJ5QcLicmhe2Ip3/D67Ed6oPqQI03mDjYaS1NQhBNtu5
// SIG // 7wPKXZ1EoNToBk8bA6839w119b+a9WToqIskdRGoP5xj
// SIG // DIv+mc0vBHhZGkJVvfIhm4Ap8zptC7xVAly0jeOv5dUG
// SIG // MCYgZjvoTmgd45bqAwundmPlGur7eleWYedLQf7s3L5+
// SIG // qfaY/xEh/9uo17SnM/gHVSGAzvnreGhOrB2LtdKoVSe5
// SIG // LbYpihXctDe76iYtL+mhxXPEpzda3bJlhPTOQ3KOEZAp
// SIG // VERBo5yltWjPCWlXxyCpl5jj9nY0nfd071bemnou8A3r
// SIG // UZrdgKIautsH7SHOiOebZGqNu+622vJta3eAYsCAaxAc
// SIG // B9BiJPla7Xad9qrTYdT45VlCYTtBSY4oVRsedSADv99j
// SIG // v/iYIAGy1bCytua0o/Qqv9erKmzQCTVMXaDc25DTLcMG
// SIG // JrRua3K0xivdtnoBexzVJr6yXqM+Ba2whIVRvGcriBkK
// SIG // X0FJFeW7r29XX+k0e4DnG6iBHKQjec6VNzCCB3EwggVZ
// SIG // oAMCAQICEzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZI
// SIG // hvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xMjAw
// SIG // BgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRl
// SIG // IEF1dGhvcml0eSAyMDEwMB4XDTIxMDkzMDE4MjIyNVoX
// SIG // DTMwMDkzMDE4MzIyNVowfDELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAg
// SIG // UENBIDIwMTAwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAw
// SIG // ggIKAoICAQDk4aZM57RyIQt5osvXJHm9DtWC0/3unAcH
// SIG // 0qlsTnXIyjVX9gF/bErg4r25PhdgM/9cT8dm95VTcVri
// SIG // fkpa/rg2Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsH
// SIG // FPPFdvWGUNzBRMhxXFExN6AKOG6N7dcP2CZTfDlhAnrE
// SIG // qv1yaa8dq6z2Nr41JmTamDu6GnszrYBbfowQHJ1S/rbo
// SIG // YiXcag/PXfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBp
// SIG // Dco2LXCOMcg1KL3jtIckw+DJj361VI/c+gVVmG1oO5pG
// SIG // ve2krnopN6zL64NF50ZuyjLVwIYwXE8s4mKyzbnijYjk
// SIG // lqwBSru+cakXW2dg3viSkR4dPf0gz3N9QZpGdc3EXzTd
// SIG // EonW/aUgfX782Z5F37ZyL9t9X4C626p+Nuw2TPYrbqgS
// SIG // Uei/BQOj0XOmTTd0lBw0gg/wEPK3Rxjtp+iZfD9M269e
// SIG // wvPV2HM9Q07BMzlMjgK8QmguEOqEUUbi0b1qGFphAXPK
// SIG // Z6Je1yh2AuIzGHLXpyDwwvoSCtdjbwzJNmSLW6CmgyFd
// SIG // XzB0kZSU2LlQ+QuJYfM2BjUYhEfb3BvR/bLUHMVr9lxS
// SIG // UV0S2yW6r1AFemzFER1y7435UsSFF5PAPBXbGjfHCBUY
// SIG // P3irRbb1Hode2o+eFnJpxq57t7c+auIurQIDAQABo4IB
// SIG // 3TCCAdkwEgYJKwYBBAGCNxUBBAUCAwEAATAjBgkrBgEE
// SIG // AYI3FQIEFgQUKqdS/mTEmr6CkTxGNSnPEP8vBO4wHQYD
// SIG // VR0OBBYEFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1Ud
// SIG // IARVMFMwUQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYBBQUH
// SIG // AgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvRG9jcy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAK
// SIG // BggrBgEFBQcDCDAZBgkrBgEEAYI3FAIEDB4KAFMAdQBi
// SIG // AEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB
// SIG // /zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvXzpoY
// SIG // xDBWBgNVHR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1p
// SIG // Y3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNS
// SIG // b29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYIKwYBBQUH
// SIG // AQEETjBMMEoGCCsGAQUFBzAChj5odHRwOi8vd3d3Lm1p
// SIG // Y3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1Jvb0NlckF1
// SIG // dF8yMDEwLTA2LTIzLmNydDANBgkqhkiG9w0BAQsFAAOC
// SIG // AgEAnVV9/Cqt4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4
// SIG // sQaTlz0xM7U518JxNj/aZGx80HU5bbsPMeTCj/ts0aGU
// SIG // GCLu6WZnOlNN3Zi6th542DYunKmCVgADsAW+iehp4LoJ
// SIG // 7nvfam++Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f
// SIG // 8449xvNo32X2pFaq95W2KFUn0CS9QKC/GbYSEhFdPSfg
// SIG // QJY4rPf5KYnDvBewVIVCs/wMnosZiefwC2qBwoEZQhlS
// SIG // dYo2wh3DYXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDS
// SIG // PeZKPmY7T7uG+jIa2Zb0j/aRAfbOxnT99kxybxCrdTDF
// SIG // NLB62FD+CljdQDzHVG2dY3RILLFORy3BFARxv2T5JL5z
// SIG // bcqOCb2zAVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxnGSgk
// SIG // ujhLmm77IVRrakURR6nxt67I6IleT53S0Ex2tVdUCbFp
// SIG // AUR+fKFhbHP+CrvsQWY9af3LwUFJfn6Tvsv4O+S3Fb+0
// SIG // zj6lMVGEvL8CwYKiexcdFYmNcP7ntdAoGokLjzbaukz5
// SIG // m/8K6TT4JDVnK+ANuOaMmdbhIurwJ0I9JZTmdHRbatGe
// SIG // Pu1+oDEzfbzL6Xu/OHBE0ZDxyKs6ijoIYn/ZcGNTTY3u
// SIG // gm2lBRDBcQZqELQdVTNYs6FwZvKhggNNMIICNQIBATCB
// SIG // +aGB0aSBzjCByzELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMG
// SIG // A1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9u
// SIG // czEnMCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOkE0MDAt
// SIG // MDVFMC1EOTQ3MSUwIwYDVQQDExxNaWNyb3NvZnQgVGlt
// SIG // ZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQCO
// SIG // HPtgVdz9EW0iPNL/BXqJoqVMf6CBgzCBgKR+MHwxCzAJ
// SIG // BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
// SIG // DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
// SIG // ZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29m
// SIG // dCBUaW1lLVN0YW1wIFBDQSAyMDEwMA0GCSqGSIb3DQEB
// SIG // CwUAAgUA6pfalzAiGA8yMDI0MDkyMDExMjcxOVoYDzIw
// SIG // MjQwOTIxMTEyNzE5WjB0MDoGCisGAQQBhFkKBAExLDAq
// SIG // MAoCBQDql9qXAgEAMAcCAQACAgjPMAcCAQACAhN3MAoC
// SIG // BQDqmSwXAgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisG
// SIG // AQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMBhqAw
// SIG // DQYJKoZIhvcNAQELBQADggEBAEraArCTEGVThVINGehD
// SIG // +Zhf65pVVdfgn5JbWyFiHfJ6K0LTso+uuEYaF/qj7y98
// SIG // f5KYIhsLGkvxSHPjae51EONFzzwheL8XUh66O4YA3+Pv
// SIG // A+TTb4Gcyp8jztZt0amklbliLUceGQ2EhYqZTLurDzpL
// SIG // Nd9cKOYn0kXb1dfDmduWB/AucpnfFnvL0iBtgltXPrv/
// SIG // eS+iiVmyjbmipwuIHZs6hJNYDpFvbWV6Ks0Sw3h+ERqh
// SIG // X9A5ovIcARrsCgoCAj2YaApr6T5SuNnBABmu6FaKYNjk
// SIG // d5WkkSIHkenpsTrKhIKnIV+YCaa+4KkaR+QU8v+TorHf
// SIG // 90yHXIBXZysvSh0xggQNMIIECQIBATCBkzB8MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQg
// SIG // VGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAezgK6SC0JFS
// SIG // gAABAAAB7DANBglghkgBZQMEAgEFAKCCAUowGgYJKoZI
// SIG // hvcNAQkDMQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJ
// SIG // BDEiBCDkn4MWjnr1E4z5rTSdVssiDbmG/3j0KbwlOKeB
// SIG // gXnbxDCB+gYLKoZIhvcNAQkQAi8xgeowgecwgeQwgb0E
// SIG // ICcJ5vVqfTfIhx21QBBbKyo/xciQIXaoMWULejAE1QqD
// SIG // MIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQG
// SIG // A1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIw
// SIG // MTACEzMAAAHs4CukgtCRUoAAAQAAAewwIgQgR0nhGixQ
// SIG // YO9x0PQfqscdOqEvrkii2tuP0Xx9z1V1PlcwDQYJKoZI
// SIG // hvcNAQELBQAEggIAOdcPwq7hjhnYRqXyercRW1OlgnIB
// SIG // Uf96qV9V/Id73e2VOzrB0SyIHzONbhyV/Weo6vFUzs9e
// SIG // AiRfJExco1tNjxiNgRDmO4M0kxtrwR0H8mt7iu+gFL/3
// SIG // FXW0CvPHzZEaq88b51aqKVswMPHfABEnvUPrR1zuy8mT
// SIG // CzsoeuA21ij/JrLOvlZ/J3ladk66lFDG/DaNy3hLfhME
// SIG // c4FiCjZDEfIuHe5zkds6WusUqerEDy/iMUNmxBoComOk
// SIG // OQDGf5CXqyMMkKImVki3W6xkMV7Ln8z1m5eAI1mJfXlc
// SIG // ifzqwCvImU9yXXv6p1QexEHAcQN4bCcAlTXqXwNcJnuw
// SIG // 7jYTyxP246iYz860rg65V6wRCIgvh8xpb86czCv50uTI
// SIG // KsCSQ5OBV2175G49eWD/FhwSPRnvNeHiKPACK6fhKHD3
// SIG // +LIKvVTweNJhVA5QS4dRIglypOFWJPIfNZTaZCa0D/Z2
// SIG // 6BpCeXPK+0Yt4RaiqoNW4PMXNTShdaFR+RSlk8zoQo4F
// SIG // vY29IiFSAtnT6AtNMbyVkHP84Uo3lTEsLTLCFFcOXtCG
// SIG // /WX+3O0uXw+p8NDHb7G+V+Kt+lmXGaWNlS+qbMzzqJoG
// SIG // nUc6EgBQOQFJZ3M7tGnsvbrlACQtYvQQikPc+mhxczBa
// SIG // 28y1x6+I5FERSrjmjDBRpVE6rkiTW2wgoYgvknw=
// SIG // End signature block
